==> joplin_3.4.4+ds.orig.tar.xz: joplin-3.4.4/readme/apps/publish_note.md <==
# Publishing a note with Joplin Cloud

Joplin Cloud allows you to publish a note to the internet to share it with any user. You simply give the URL and the recipient will see the note and any attached images, and the note will also be updated any time you change something.

To publish a note, you will need the Joplin desktop application. You can right-click on any note and select "Publish note..." from the context menu. You can also select multiple notes, and each will have its own publish link.

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/ContextMenu.jpg" width="75%"/>

After that a dialog opens showing you the note - from there you just need to click on "Copy shareable link" to create the share link and copy it to the clipboard.

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/Dialog.jpg" width="75%"/>

You can then share this link with anyone and they will be able to see the note in their browser:

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/Browser.jpg" width="75%"/>

## Unpublishing a note

After publishing a note, it can be unpublished by right-clicking on it in the desktop application, and selecting "Publish note..."

From there, clicking on the "Share" icon will unpublish the note.

## Customising the publishing banner

Using Joplin Cloud Pro or Teams, you have the ability to customise the banner that is displayed at the top of the notes. That includes changing the logo, title or colour of the banner. To do so, open your [Profile page](https://joplincloud.com/users/me) and go to the "Published note banner" section:

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/Banner.png" width="75%"/>

==> joplin_3.6.2+ds.orig.tar.xz: joplin-3.6.2/readme/apps/publish_note.md <==
# Publishing a note with Joplin Cloud

Joplin Cloud allows you to publish a note to the internet to share it with any user. You simply give the URL and the recipient will see the note and any attached images, and the note will also be updated any time you change something.

To publish a note, you will need the Joplin desktop application. You can right-click on any note and select "Publish note..." from the context menu. You can also select multiple notes, and each will have its own publish link.

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/ContextMenu.jpg" width="75%"/>

After that a dialog opens showing you the note - from there you just need to click on "Copy shareable link" to create the share link and copy it to the clipboard.

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/Dialog.jpg" width="75%"/>

You can then share this link with anyone and they will be able to see the note in their browser:

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/Browser.jpg" width="75%"/>

## Unpublishing a note

After publishing a note, it can be unpublished by right-clicking on it in the desktop application, and selecting "Publish note..."

From there, clicking on the "Share" icon will unpublish the note.

## Customising the publishing banner

Using Joplin Cloud Pro or Teams, you have the ability to customise the banner that is displayed at the top of the notes. That includes changing the logo, title or colour of the banner. To do so, open your [Profile page](https://joplincloud.com/users/me) and go to the "Published note banner" section:

<img src="https://raw.githubusercontent.com/laurent22/joplin/dev/Assets/WebsiteAssets/images/publish_note/Banner.png" width="75%"/>

## Video Tutorial

For a video tutorial on how to publish a note and customise the banner please click on the thumbnail:

[![Watch the video](https://img.youtube.com/vi/i1xgInm0PTE/hqdefault.jpg)](https://youtu.be/i1xgInm0PTE)
